<img src="https://hpcflow.github.io/docs/stable/_static/images/logo-v2.png" width="250" alt="hpcFlow logo"/>

**hpcFlow manages your scientific workflows**

Documentation: [https://hpcflow.github.io/docs](https://hpcflow.github.io/docs)

## Acknowledgements
hpcFlow was developed using funding from the [LightForm](https://lightform.org.uk/) EPSRC programme grant ([EP/R001715/1](https://gow.epsrc.ukri.org/NGBOViewGrant.aspx?GrantRef=EP/R001715/1))



<img src="https://lightform-group.github.io/wiki/assets/images/site/lightform-logo.png" width="150"/>
